<?php

namespace Drupal\form_field_access\Entity;

use Drupal\Core\Config\Entity\ConfigEntityInterface;

/**
 * Form Field Access Interface.
 */
interface FormFieldAccessInterface extends ConfigEntityInterface {

  /**
   * Get referred entity type id.
   *
   * @return string|null
   *   Entity Type Id.
   */
  public function getReferredEntityTypeId(): ?string;

  /**
   * Get referred bundle.
   *
   * @return string|null
   *   Bundle.
   */
  public function getReferredBundle(): ?string;

  /**
   * Get fields settings.
   *
   * @return array
   *   Fields settings.
   */
  public function getDisallowedFields(): array;

  /**
   * Get field associated roles.
   *
   * @return array
   *   Field roles array.
   */
  public function getDisallowedFieldRoles(string $field_name): array;

  /**
   * Get fields marked as required.
   *
   * @return array
   *   Required fields list.
   */
  public function getRequiredFields(): array;

  /**
   * Get field marked as required for associated roles.
   *
   * @return array
   *   Field roles array.
   */
  public function getRequiredFieldRoles(string $field_name): array;

}
