<?php

namespace Drupal\form_field_access;

use Drupal\Core\Config\Entity\ConfigEntityListBuilder;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Render\Markup;

/**
 * Form Field Access list builder.
 */
class FormFieldAccessListBuilder extends ConfigEntityListBuilder {

  /**
   * {@inheritdoc}
   */
  public function buildHeader() {
    $header['id'] = $this->t('ID');
    $header['disallowed'] = $this->t('Disallowed');
    $header['required'] = $this->t('Required');

    return $header + parent::buildHeader();
  }

  /**
   * {@inheritdoc}
   */
  public function buildRow(EntityInterface $entity) {
    $row['id'] = $entity->id();

    // Display "disallowed" summary.
    $disallowed_fields = $entity->getDisallowedFields();
    $disallowed_fields_output = [];
    foreach ($disallowed_fields as $disallowed_field => $disallowed_field_roles) {
      $disallowed_fields_output[] = '<strong>' . $disallowed_field . '</strong>: ' . implode(', ', array_keys($disallowed_field_roles));
    }
    $row['disallowed'] = Markup::create(implode('<br>', $disallowed_fields_output));

    // Display "required" summary.
    $required_fields = $entity->getRequiredFields();
    $required_fields_output = [];
    foreach ($required_fields as $required_field => $required_field_roles) {
      $required_fields_output[] = '<strong>' . $required_field . '</strong>: ' . implode(', ', array_keys($required_field_roles));
    }
    $row['required'] = Markup::create(implode('<br>', $required_fields_output));

    return $row + parent::buildRow($entity);
  }

}
